struct ServoRendererWebView {
id: WebViewId,
weak_handle: Weak<RefCell<WebViewInner>>,
}Expand description
A structure used to expose a view of the WebView to the Servo
renderer, without having the Servo renderer depend on the embedding layer.
Fields
id: WebViewIdweak_handle: Weak<RefCell<WebViewInner>>Trait Implementations
Sourceimpl WebViewTrait for ServoRendererWebView
impl WebViewTrait for ServoRendererWebView
fn id(&self) -> WebViewId
fn screen_geometry(&self) -> Option<ScreenGeometry>
fn set_animating(&self, new_value: bool)
Sourcefn notify_viewport_updated(&self)
fn notify_viewport_updated(&self)
Notify the embedding layer that this
WebView’s viewport geometry changed — its size, page
or pinch zoom, or HiDPI scale — so it can refresh geometry, such as the accessibility root
node, that the embedder derives from the viewport rather than from a pipeline update.Auto Trait Implementations
impl Freeze for ServoRendererWebView
impl !RefUnwindSafe for ServoRendererWebView
impl !Send for ServoRendererWebView
impl !Sync for ServoRendererWebView
impl Unpin for ServoRendererWebView
impl UnsafeUnpin for ServoRendererWebView
impl !UnwindSafe for ServoRendererWebView