struct ServoRendererWebView {
id: WebViewId,
weak_handle: Weak<RefCell<WebViewInner>>,
}Expand description
A structure used to expose a view of the WebView to the Servo
renderer, without having the Servo renderer depend on the embedding layer.
Fields
id: WebViewIdweak_handle: Weak<RefCell<WebViewInner>>Trait Implementations
Sourceimpl WebViewTrait for ServoRendererWebView
impl WebViewTrait for ServoRendererWebView
fn id(&self) -> WebViewId
fn screen_geometry(&self) -> Option<ScreenGeometry>
fn set_animating(&self, new_value: bool)