pub(crate) struct WebViewInner {Show 20 fields
pub(crate) id: WebViewId,
pub(crate) servo: Servo,
pub(crate) delegate: Rc<dyn WebViewDelegate>,
pub(crate) clipboard_delegate: Rc<dyn ClipboardDelegate>,
pub(crate) gamepad_delegate: Rc<dyn GamepadDelegate>,
pub(crate) accesskit_tree_id: Option<TreeId>,
pub(crate) grafted_accesskit_tree_id: Option<TreeId>,
grafted_accesskit_tree_epoch: Option<Epoch>,
rendering_context: Rc<dyn RenderingContext>,
user_content_manager: Option<Rc<UserContentManager>>,
hidpi_scale_factor: Scale<f32, DeviceIndependentPixel, DevicePixel>,
load_status: LoadStatus,
status_text: Option<String>,
page_title: Option<String>,
favicon: Option<Image>,
focused: bool,
animating: bool,
cursor: Cursor,
back_forward_list: Vec<Url>,
back_forward_list_index: usize,
}Fields
id: WebViewIdservo: Servodelegate: Rc<dyn WebViewDelegate>clipboard_delegate: Rc<dyn ClipboardDelegate>gamepad_delegate: Rc<dyn GamepadDelegate>accesskit_tree_id: Option<TreeId>AccessKit subtree id for this WebView, if accessibility is active.
Set by WebView::set_accessibility_active(), and forwarded to the constellation via
EmbedderToConstellationMessage::SetAccessibilityActive.
grafted_accesskit_tree_id: Option<TreeId>TreeId of the web contents of this WebView’s active top-level pipeline,
which is grafted into the tree for this WebView.
grafted_accesskit_tree_epoch: Option<Epoch>A counter for changes to the grafted accesskit tree for this webview.
See Self::grafted_accesskit_tree_id.
rendering_context: Rc<dyn RenderingContext>user_content_manager: Option<Rc<UserContentManager>>hidpi_scale_factor: Scale<f32, DeviceIndependentPixel, DevicePixel>load_status: LoadStatusstatus_text: Option<String>page_title: Option<String>favicon: Option<Image>focused: boolanimating: boolcursor: Cursorback_forward_list: Vec<Url>The back / forward list of this WebView.
back_forward_list_index: usizeThe current index in the back / forward list.